# This spec file has been automatically updated
Version:        195.6
Release: 1%{?dist}
#
# This file is maintained at the following location:
# https://github.com/cockpit-project/cockpit/blob/master/tools/cockpit.spec
#
# If you are editing this file in another location, changes will likely
# be clobbered the next time an automated release is done.
#
# Check first cockpit-devel@lists.fedorahosted.org
#
# Globals that may be defined elsewhere
#  * Version 122
#  * wip 1
#

# earliest base that the subpackages work on; the instances of this get computed/updated
# by tools/gen-spec-dependencies during "make dist", but keep a hardcoded fallback
%define required_base 122

# we generally want CentOS packages to be like RHEL; special cases need to check %{centos} explicitly
%if 0%{?centos}
%define rhel %{centos}
%endif

%if "%{!?__python3:1}"
%define __python3 /usr/bin/python3
%endif

# for testing this already gets set in fedora.install, as we want the target
# VERSION_ID, not the mock chroot's one
%if "%{!?os_version_id:1}"
%define os_version_id %(. /etc/os-release; echo $VERSION_ID)
%endif

%define _hardened_build 1

# define to build the dashboard
# define build_dashboard 1

# build basic packages like cockpit-bridge
%define build_basic 1
# build optional extensions like cockpit-docker
%define build_optional 1

# cockpit's firewall service definition moved to firewalld
%if 0%{?fedora} >= 29 || 0%{?rhel} >= 8
%define firewalld_service 0
%else
%define firewalld_service 1
%endif

%define __lib lib

# on RHEL 7.x we build subscriptions; superseded later by
# external subscription-manager-cockpit
%if (0%{?rhel} >= 7 && 0%{?rhel} < 8) && 0%{?centos} == 0
%define build_subscriptions 1
%endif

# cockpit-kubernetes is 64 bit arches only
%ifarch aarch64 x86_64 ppc64le s390x %{arm} %{ix86}
%define build_kubernetes 1
# the primary go-toolset-7-golang is too old (unfixed CVEs), use latest one
%global go_scl_prefix go-toolset-1.12-
# go-toolset-1.12-golang doesn't have "go" in $PATH
%define golang_def GOLANG=/opt/rh/go-toolset-1.12/root/usr/lib/go-toolset-1.12-golang/bin/go
%else
%define golang_def
%endif

# cockpit-machines-ovirt is RHEL 7 and Fedora < 30 only
%if (0%{?fedora} && 0%{?fedora} < 30) || (0%{?rhel} >= 7 && 0%{?rhel} < 8)
%define build_ovirt 1
%endif

%if 0%{?rhel} >= 7
%define vdo_on_demand 1
%define insights_client_on_demand 1
%endif

Name:           cockpit
Summary:        Web Console for Linux servers

License:        LGPLv2+
URL:            https://cockpit-project.org/

%if %{defined wip}
Source0:        cockpit-%{version}.tar.gz
%else
Source0:        https://github.com/cockpit-project/cockpit/releases/download/%{version}/cockpit-%{version}.tar.xz
%endif

Patch0001: 0001-test-Disable-packet-channel-large.patch

BuildRequires: gcc
BuildRequires: pkgconfig(gio-unix-2.0)
BuildRequires: pkgconfig(json-glib-1.0)
BuildRequires: pkgconfig(polkit-agent-1) >= 0.105
BuildRequires: pam-devel

BuildRequires: autoconf automake
%if 0%{?fedora} || 0%{?rhel} >= 8
BuildRequires: /usr/bin/python3
%else
BuildRequires: /usr/bin/python2
%endif
BuildRequires: intltool
%if %{defined build_dashboard}
BuildRequires: libssh-devel >= 0.7.1
%endif
BuildRequires: openssl-devel
BuildRequires: zlib-devel
BuildRequires: krb5-devel
BuildRequires: libxslt-devel
BuildRequires: docbook-style-xsl
BuildRequires: glib-networking
BuildRequires: sed

BuildRequires: glib2-devel >= 2.37.4
BuildRequires: systemd-devel
BuildRequires: pcp-libs-devel
BuildRequires: krb5-server
BuildRequires: gdb
BuildRequires: openssh-clients

# For documentation
BuildRequires: xmlto

# This is the "cockpit" metapackage. It should only
# Require, Suggest or Recommend other cockpit-xxx subpackages

Requires: cockpit-bridge
Requires: cockpit-ws
Requires: cockpit-system

# Optional components
%if 0%{?fedora} || 0%{?rhel} >= 8
%if 0%{?rhel} == 0
Recommends: cockpit-dashboard
%ifarch x86_64 %{arm} aarch64 ppc64le i686 s390x
Recommends: (cockpit-docker if /usr/bin/docker)
%endif
%endif
Recommends: (cockpit-networkmanager if NetworkManager)
Recommends: (cockpit-storaged if udisks2)
Recommends: cockpit-packagekit
%if 0%{?rhel} >= 8 && 0%{?centos} == 0
Recommends: subscription-manager-cockpit
%endif
Suggests: cockpit-pcp
%if 0%{?build_kubernetes}
Suggests: cockpit-kubernetes
%endif
Suggests: cockpit-selinux
%endif

%prep
%setup -q -n cockpit-%{version}
%autopatch -p1

%build
exec 2>&1
%configure \
    %{golang_def} \
    --disable-silent-rules \
    --with-cockpit-user=cockpit-ws \
    --with-selinux-config-type=etc_t \
%if 0%{?rhel} >= 7 && 0%{?rhel} < 8
    --without-storaged-iscsi-sessions \
%endif
    --with-appstream-data-packages='[ "appstream-data" ]' \
    %{!?build_dashboard:--disable-ssh} \
    --with-nfs-client-package='"nfs-utils"' \
    %{?vdo_on_demand:--with-vdo-package='"vdo"'} \
    %{?insights_client_on_demand:--with-insights-client-package='"insights-client"'}
make -j4 %{?extra_flags} all

%check
exec 2>&1
make -j4 check

%install
make install DESTDIR=%{buildroot}
make install-tests DESTDIR=%{buildroot}
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/pam.d
install -p -m 644 tools/cockpit.pam $RPM_BUILD_ROOT%{_sysconfdir}/pam.d/cockpit
rm -f %{buildroot}/%{_libdir}/cockpit/*.so
%if 0%{?firewalld_service} == 0
rm -f %{buildroot}/%{_prefix}/%{__lib}/firewalld/services/cockpit.xml
%endif
install -p -m 644 AUTHORS COPYING README.md %{buildroot}%{_docdir}/cockpit/

# Build the package lists for resource packages
echo '%dir %{_datadir}/cockpit/base1' > base.list
find %{buildroot}%{_datadir}/cockpit/base1 -type f >> base.list
echo '%{_sysconfdir}/cockpit/machines.d' >> base.list
echo %{buildroot}%{_datadir}/polkit-1/actions/org.cockpit-project.cockpit-bridge.policy >> base.list
# RHEL 7 needs to keep cockpit-ssh in dashboard for backwards compat
%if 0%{?rhel} == 7
find %{buildroot}%{_datadir}/cockpit/ssh -type f >> dashboard.list
echo '%{_libexecdir}/cockpit-ssh' >> dashboard.list
%else
find %{buildroot}%{_datadir}/cockpit/ssh -type f >> base.list
echo '%{_libexecdir}/cockpit-ssh' >> base.list
%endif

%if %{defined build_dashboard}
echo '%dir %{_datadir}/cockpit/dashboard' >> dashboard.list
find %{buildroot}%{_datadir}/cockpit/dashboard -type f >> dashboard.list
%else
rm -rf %{buildroot}/%{_datadir}/cockpit/dashboard
rm -rf %{buildroot}/%{_datadir}/%{name}/ssh
touch dashboard.list
%endif

echo '%dir %{_datadir}/cockpit/pcp' >> pcp.list
find %{buildroot}%{_datadir}/cockpit/pcp -type f >> pcp.list

echo '%dir %{_datadir}/cockpit/realmd' >> system.list
find %{buildroot}%{_datadir}/cockpit/realmd -type f >> system.list

echo '%dir %{_datadir}/cockpit/tuned' >> system.list
find %{buildroot}%{_datadir}/cockpit/tuned -type f >> system.list

echo '%dir %{_datadir}/cockpit/shell' >> system.list
find %{buildroot}%{_datadir}/cockpit/shell -type f >> system.list

echo '%dir %{_datadir}/cockpit/systemd' >> system.list
find %{buildroot}%{_datadir}/cockpit/systemd -type f >> system.list

echo '%dir %{_datadir}/cockpit/users' >> system.list
find %{buildroot}%{_datadir}/cockpit/users -type f >> system.list

echo '%dir %{_datadir}/cockpit/kdump' >> kdump.list
find %{buildroot}%{_datadir}/cockpit/kdump -type f >> kdump.list

echo '%dir %{_datadir}/cockpit/sosreport' > sosreport.list
find %{buildroot}%{_datadir}/cockpit/sosreport -type f >> sosreport.list

%if %{defined build_subscriptions}
echo '%dir %{_datadir}/cockpit/subscriptions' >> system.list
find %{buildroot}%{_datadir}/cockpit/subscriptions -type f >> system.list
%else
rm -rf %{buildroot}/%{_datadir}/cockpit/subscriptions
%endif

echo '%dir %{_datadir}/cockpit/storaged' > storaged.list
find %{buildroot}%{_datadir}/cockpit/storaged -type f >> storaged.list

echo '%dir %{_datadir}/cockpit/networkmanager' > networkmanager.list
find %{buildroot}%{_datadir}/cockpit/networkmanager -type f >> networkmanager.list

echo '%dir %{_datadir}/cockpit/packagekit' >> packagekit.list
find %{buildroot}%{_datadir}/cockpit/packagekit -type f >> packagekit.list

echo '%dir %{_datadir}/cockpit/apps' >> packagekit.list
find %{buildroot}%{_datadir}/cockpit/apps -type f >> packagekit.list

echo '%dir %{_datadir}/cockpit/machines' > machines.list
find %{buildroot}%{_datadir}/cockpit/machines -type f >> machines.list

%if 0%{?build_ovirt}
echo '%dir %{_datadir}/cockpit/ovirt' > ovirt.list
find %{buildroot}%{_datadir}/cockpit/ovirt -type f >> ovirt.list
%else
rm -rf %{buildroot}/%{_datadir}/cockpit/ovirt
touch ovirt.list
%endif

echo '%dir %{_datadir}/cockpit/selinux' > selinux.list
find %{buildroot}%{_datadir}/cockpit/selinux -type f >> selinux.list

echo '%dir %{_datadir}/cockpit/playground' > tests.list
find %{buildroot}%{_datadir}/cockpit/playground -type f >> tests.list

%ifarch x86_64 %{arm} aarch64 ppc64le i686 s390x
%if 0%{?fedora} || 0%{?rhel} < 8
echo '%dir %{_datadir}/cockpit/docker' > docker.list
find %{buildroot}%{_datadir}/cockpit/docker -type f >> docker.list
%else
rm -rf %{buildroot}/%{_datadir}/cockpit/docker
touch docker.list
%endif
%else
rm -rf %{buildroot}/%{_datadir}/cockpit/docker
touch docker.list
%endif

%if 0%{?build_kubernetes}
%if %{defined wip}
%else
rm %{buildroot}/%{_datadir}/cockpit/kubernetes/override.json
%endif
echo '%dir %{_datadir}/cockpit/kubernetes' > kubernetes.list
find %{buildroot}%{_datadir}/cockpit/kubernetes -type f >> kubernetes.list
%else
rm -rf %{buildroot}/%{_datadir}/cockpit/kubernetes
rm -f %{buildroot}/%{_libexecdir}/cockpit-kube-auth
rm -f %{buildroot}/%{_libexecdir}/cockpit-kube-launch
rm %{buildroot}/%{_libexecdir}/cockpit-stub
touch kubernetes.list
%endif

# when not building basic packages, remove their files
%if 0%{?build_basic} == 0
for pkg in base1 branding motd kdump networkmanager realmd selinux shell sosreport ssh static systemd tuned users; do
    rm -r %{buildroot}/%{_datadir}/cockpit/$pkg
    rm -f %{buildroot}/%{_datadir}/metainfo/org.cockpit-project.cockpit-${pkg}.metainfo.xml
done
for data in doc locale man pixmaps polkit-1; do
    rm -r %{buildroot}/%{_datadir}/$data
done
for lib in systemd tmpfiles.d firewalld; do
    rm -r %{buildroot}/%{_prefix}/%{__lib}/$lib
done
for libexec in cockpit-askpass cockpit-session cockpit-ws cockpit-desktop; do
    rm %{buildroot}/%{_libexecdir}/$libexec
done
rm -r %{buildroot}/%{_libdir}/security %{buildroot}/%{_sysconfdir}/pam.d %{buildroot}/%{_sysconfdir}/motd.d %{buildroot}/%{_sysconfdir}/issue.d
rm %{buildroot}/usr/bin/cockpit-bridge %{buildroot}/usr/sbin/remotectl
rm -f %{buildroot}%{_libexecdir}/cockpit-ssh
rm -f %{buildroot}%{_datadir}/metainfo/cockpit.appdata.xml
%endif

# when not building optional packages, remove their files
%if 0%{?build_optional} == 0
for pkg in apps dashboard docker kubernetes machines ovirt packagekit pcp playground storaged; do
    rm -rf %{buildroot}/%{_datadir}/cockpit/$pkg
done
# files from -tests
rm -r %{buildroot}/%{_prefix}/%{__lib}/cockpit-test-assets %{buildroot}/%{_sysconfdir}/cockpit/cockpit.conf
# files from -pcp
rm -r %{buildroot}/%{_libexecdir}/cockpit-pcp %{buildroot}/%{_localstatedir}/lib/pcp/
# files from -kubernetes
rm -f %{buildroot}/%{_libexecdir}/cockpit-kube-auth %{buildroot}/%{_libexecdir}/cockpit-kube-launch %{buildroot}/%{_libexecdir}/cockpit-stub
# files from -machines
rm -f %{buildroot}/%{_prefix}/share/metainfo/org.cockpit-project.cockpit-machines.metainfo.xml
# files from -storaged
rm -f %{buildroot}/%{_prefix}/share/metainfo/org.cockpit-project.cockpit-storaged.metainfo.xml
%endif

sed -i "s|%{buildroot}||" *.list

# Build the package lists for debug package, and move debug files to installed locations
find %{buildroot}/usr/src/debug%{_datadir}/cockpit -type f -o -type l > debug.partial
sed -i "s|%{buildroot}/usr/src/debug||" debug.partial
sed -n 's/\.map\(\.gz\)\?$/\0/p' *.list >> debug.partial
sed -i '/\.map\(\.gz\)\?$/d' *.list
tar -C %{buildroot}/usr/src/debug -cf - . | tar -C %{buildroot} -xf -
rm -rf %{buildroot}/usr/src/debug

# On RHEL kdump, networkmanager, selinux, and sosreport are part of the system package
%if 0%{?rhel}
cat kdump.list sosreport.list networkmanager.list selinux.list >> system.list
rm -f %{buildroot}%{_datadir}/metainfo/org.cockpit-project.cockpit-sosreport.metainfo.xml
rm -f %{buildroot}%{_datadir}/metainfo/org.cockpit-project.cockpit-kdump.metainfo.xml
rm -f %{buildroot}%{_datadir}/pixmaps/cockpit-sosreport.png
%endif

%if 0%{?rhel}
rm -f %{buildroot}%{_datadir}/metainfo/org.cockpit-project.cockpit-selinux.metainfo.xml
%endif

%if 0%{?build_basic}
%find_lang cockpit
%endif

# dwz has trouble with the go binaries
# https://fedoraproject.org/wiki/PackagingDrafts/Go
%global _dwz_low_mem_die_limit 0
%if 0%{?fedora} || 0%{?rhel} >= 8
%global _debugsource_packages 1
%global _debuginfo_subpackages 0
%endif

%define find_debug_info %{_rpmconfigdir}/find-debuginfo.sh %{?_missing_build_ids_terminate_build:--strict-build-id} %{?_include_minidebuginfo:-m} %{?_find_debuginfo_dwz_opts} %{?_find_debuginfo_opts} %{?_debugsource_packages:-S debugsourcefiles.list} "%{_builddir}/%{?buildsubdir}"

# Redefine how debug info is built to slip in our extra debug files
%define __debug_install_post   \
   %{find_debug_info} \
   cat debug.partial >> %{_builddir}/%{?buildsubdir}/debugfiles.list \
%{nil}

# -------------------------------------------------------------------------------
# Basic Sub-packages

%if 0%{?build_basic}

%description
The Cockpit Web Console enables users to administer GNU/Linux servers using a
web browser.

It offers network configuration, log inspection, diagnostic reports, SELinux
troubleshooting, interactive command-line sessions, and more.

%files
%{_docdir}/cockpit/AUTHORS
%{_docdir}/cockpit/COPYING
%{_docdir}/cockpit/README.md
%dir %{_datadir}/cockpit
%{_datadir}/metainfo/cockpit.appdata.xml
%{_datadir}/pixmaps/cockpit.png
%doc %{_mandir}/man1/cockpit.1.gz


%package bridge
Summary: Cockpit bridge server-side component
Requires: glib-networking
%if 0%{?rhel} != 7
Provides: cockpit-ssh = %{version}-%{release}
# cockpit-ssh moved from dashboard to bridge in 171
Conflicts: cockpit-dashboard < 170.x
# PR #10430 dropped workaround for ws' inability to understand x-host-key challenge
Conflicts: cockpit-ws < 181.x
%endif

%description bridge
The Cockpit bridge component installed server side and runs commands on the
system on behalf of the web based user interface.

%files bridge -f base.list
%doc %{_mandir}/man1/cockpit-bridge.1.gz
%{_bindir}/cockpit-bridge
%{_libexecdir}/cockpit-askpass

%package doc
Summary: Cockpit deployment and developer guide

%description doc
The Cockpit Deployment and Developer Guide shows sysadmins how to
deploy Cockpit on their machines as well as helps developers who want to
embed or extend Cockpit.

%files doc
%exclude %{_docdir}/cockpit/AUTHORS
%exclude %{_docdir}/cockpit/COPYING
%exclude %{_docdir}/cockpit/README.md
%{_docdir}/cockpit

%package system
Summary: Cockpit admin interface package for configuring and troubleshooting a system
BuildArch: noarch
Requires: cockpit-bridge >= %{version}-%{release}
Requires: shadow-utils
Requires: grep
Requires: libpwquality
Requires: /usr/bin/date
Provides: cockpit-realmd = %{version}-%{release}
Provides: cockpit-shell = %{version}-%{release}
Provides: cockpit-systemd = %{version}-%{release}
Provides: cockpit-tuned = %{version}-%{release}
Provides: cockpit-users = %{version}-%{release}
%if 0%{?rhel}
Provides: cockpit-networkmanager = %{version}-%{release}
Obsoletes: cockpit-shell <= %{version}-%{release}
Obsoletes: cockpit-networkmanager
Requires: NetworkManager
Provides: cockpit-kdump = %{version}-%{release}
Requires: kexec-tools
# Optional components (only when soft deps are supported)
%if 0%{?fedora} || 0%{?rhel} >= 8
Recommends: polkit
%endif
%if 0%{?rhel} >= 8
Recommends: NetworkManager-team
Recommends: setroubleshoot-server >= 3.3.3
%endif
Provides: cockpit-selinux = %{version}-%{release}
Provides: cockpit-sosreport = %{version}-%{release}
%endif
%if %{defined build_subscriptions}
Provides: cockpit-subscriptions = %{version}-%{release}
Requires: subscription-manager >= 1.13
%endif
# NPM modules which are also available as packages
Provides: bundled(js-jquery) = 3.4.0
Provides: bundled(js-moment) = 2.24.0
Provides: bundled(nodejs-flot) = 0.8.3
Provides: bundled(nodejs-promise) = 8.0.3
Provides: bundled(xstatic-bootstrap-datepicker-common) = 1.8.0
Provides: bundled(xstatic-patternfly-common) = 3.58.0

%description system
This package contains the Cockpit shell and system configuration interfaces.

%files system -f system.list

%package ws
Summary: Cockpit Web Service
Requires: glib-networking
Requires: openssl
Requires: glib2 >= 2.37.4
# RHEL/CentOS 7 has firewalld 0.6.x, but does not ship cockpit service
%if 0%{?rhel} != 7
%if 0%{?firewalld_service}
Conflicts: firewalld >= 0.6.0-1
%else
Conflicts: firewalld < 0.6.0-1
%endif
%endif
%if 0%{?fedora} || 0%{?rhel} >= 8
Recommends: sscg >= 2.3
Recommends: system-logos
%endif
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

%description ws
The Cockpit Web Service listens on the network, and authenticates users.

%files ws -f cockpit.lang
%doc %{_mandir}/man1/cockpit-desktop.1.gz
%doc %{_mandir}/man5/cockpit.conf.5.gz
%doc %{_mandir}/man8/cockpit-ws.8.gz
%doc %{_mandir}/man8/remotectl.8.gz
%doc %{_mandir}/man8/pam_ssh_add.8.gz
%config(noreplace) %{_sysconfdir}/cockpit/ws-certs.d
%config(noreplace) %{_sysconfdir}/pam.d/cockpit
%config %{_sysconfdir}/issue.d/cockpit.issue
%config %{_sysconfdir}/motd.d/cockpit
%{_datadir}/cockpit/motd/update-motd
%{_datadir}/cockpit/motd/inactive.motd
%{_unitdir}/cockpit.service
%{_unitdir}/cockpit-motd.service
%{_unitdir}/cockpit.socket
%if 0%{?firewalld_service}
%{_prefix}/%{__lib}/firewalld/services/cockpit.xml
%endif
%{_prefix}/%{__lib}/tmpfiles.d/cockpit-tempfiles.conf
%{_sbindir}/remotectl
%{_libdir}/security/pam_ssh_add.so
%{_libexecdir}/cockpit-ws
%{_libexecdir}/cockpit-desktop
%attr(4750, root, cockpit-ws) %{_libexecdir}/cockpit-session
%attr(775, -, wheel) %{_localstatedir}/lib/cockpit
%{_datadir}/cockpit/static
%{_datadir}/cockpit/branding

%pre ws
getent group cockpit-ws >/dev/null || groupadd -r cockpit-ws
getent passwd cockpit-ws >/dev/null || useradd -r -g cockpit-ws -d /nonexisting -s /sbin/nologin -c "User for cockpit-ws" cockpit-ws

%post ws
%systemd_post cockpit.socket
# firewalld only partially picks up changes to its services files without this
test -f %{_bindir}/firewall-cmd && firewall-cmd --reload --quiet || true

%preun ws
%systemd_preun cockpit.socket

%postun ws
%systemd_postun_with_restart cockpit.socket
%systemd_postun_with_restart cockpit.service

# -------------------------------------------------------------------------------
# Sub-packages that are part of cockpit-system in RHEL/CentOS, but separate in Fedora

%if 0%{?rhel} == 0

%package kdump
Summary: Cockpit user interface for kernel crash dumping
Requires: cockpit-bridge >= 122
Requires: cockpit-shell >= 122
Requires: kexec-tools
BuildArch: noarch

%description kdump
The Cockpit component for configuring kernel crash dumping.

%files kdump -f kdump.list
%{_datadir}/metainfo/org.cockpit-project.cockpit-kdump.metainfo.xml

%package sosreport
Summary: Cockpit user interface for diagnostic reports
Requires: cockpit-bridge >= 122
Requires: cockpit-shell >= 122
Requires: sos
BuildArch: noarch

%description sosreport
The Cockpit component for creating diagnostic reports with the
sosreport tool.

%files sosreport -f sosreport.list
%{_datadir}/metainfo/org.cockpit-project.cockpit-sosreport.metainfo.xml
%{_datadir}/pixmaps/cockpit-sosreport.png

%package networkmanager
Summary: Cockpit user interface for networking, using NetworkManager
Requires: cockpit-bridge >= 122
Requires: cockpit-shell >= 122
Requires: NetworkManager
# Optional components (only when soft deps are supported)
%if 0%{?fedora} || 0%{?rhel} >= 8
Recommends: NetworkManager-team
%endif
BuildArch: noarch

%description networkmanager
The Cockpit component for managing networking.  This package uses NetworkManager.

%files networkmanager -f networkmanager.list

%endif

%if 0%{?rhel} == 0

%package selinux
Summary: Cockpit SELinux package
Requires: cockpit-bridge >= 122
Requires: cockpit-shell >= 122
%if 0%{?fedora} || 0%{?rhel} >= 8
Requires: setroubleshoot-server >= 3.3.3
%endif
BuildArch: noarch

%description selinux
This package contains the Cockpit user interface integration with the
utility setroubleshoot to diagnose and resolve SELinux issues.

%files selinux -f selinux.list
%{_datadir}/metainfo/org.cockpit-project.cockpit-selinux.metainfo.xml

%endif

%else # build basic packages

# RPM requires this
%description
Dummy package from building optional packages only; never install or publish me.

%endif # build basic packages

# -------------------------------------------------------------------------------
# Sub-packages that are optional extensions

%if 0%{?build_optional}

%package -n cockpit-storaged
Summary: Cockpit user interface for storage, using udisks
Requires: cockpit-shell >= 122
Requires: udisks2 >= 2.6
%if 0%{?rhel} == 7
# Recommends: not supported in RHEL <= 7
Requires: udisks2-lvm2 >= 2.6
Requires: udisks2-iscsi >= 2.6
Requires: device-mapper-multipath
Requires: python
Requires: python-dbus
%else
Recommends: udisks2-lvm2 >= 2.6
Recommends: udisks2-iscsi >= 2.6
Recommends: device-mapper-multipath
Recommends: clevis-luks
Requires: %{__python3}
Requires: python3-dbus
%endif
BuildArch: noarch

%description -n cockpit-storaged
The Cockpit component for managing storage.  This package uses udisks.

%files -n cockpit-storaged -f storaged.list
%{_datadir}/metainfo/org.cockpit-project.cockpit-storaged.metainfo.xml

%package -n cockpit-tests
Summary: Tests for Cockpit
Requires: cockpit-bridge >= 138
Requires: cockpit-system >= 138
Requires: openssh-clients
Provides: cockpit-test-assets = %{version}-%{release}

%description -n cockpit-tests
This package contains tests and files used while testing Cockpit.
These files are not required for running Cockpit.

%files -n cockpit-tests -f tests.list
%config(noreplace) %{_sysconfdir}/cockpit/cockpit.conf
%{_prefix}/%{__lib}/cockpit-test-assets

%package -n cockpit-machines
BuildArch: noarch
Summary: Cockpit user interface for virtual machines
Requires: cockpit-bridge >= 122
Requires: cockpit-system >= 122
%if 0%{?rhel} == 7
Requires: libvirt
%else
Requires: (libvirt-daemon-kvm or libvirt)
%endif
Requires: libvirt-client
%if 0%{?centos} == 0
Requires: libvirt-dbus >= 1.2.0
%endif
%if 0%{?fedora} || 0%{?rhel} >= 8
# Optional components
Recommends: virt-install
Recommends: libosinfo
Recommends: python3-gobject-base
%endif

%description -n cockpit-machines
The Cockpit components for managing virtual machines.

If "virt-install" is installed, you can also create new virtual machines.

%files -n cockpit-machines -f machines.list
%{_datadir}/metainfo/org.cockpit-project.cockpit-machines.metainfo.xml

%if 0%{?build_ovirt}

%package -n cockpit-machines-ovirt
BuildArch: noarch
Summary: Cockpit user interface for oVirt virtual machines
Requires: cockpit-bridge >= 122
Requires: cockpit-system >= 122
%if 0%{?rhel} == 7
Requires: libvirt
%else
Requires: (libvirt-daemon-kvm or libvirt)
%endif
Requires: libvirt-client

%description -n cockpit-machines-ovirt
The Cockpit components for managing oVirt virtual machines.

%files -n cockpit-machines-ovirt -f ovirt.list

%endif

%package -n cockpit-pcp
Summary: Cockpit PCP integration
Requires: cockpit-bridge >= 134.x
Requires: pcp

%description -n cockpit-pcp
Cockpit support for reading PCP metrics and loading PCP archives.

%files -n cockpit-pcp -f pcp.list
%{_libexecdir}/cockpit-pcp
%{_localstatedir}/lib/pcp/config/pmlogconf/tools/cockpit

%post -n cockpit-pcp
# HACK - https://bugzilla.redhat.com/show_bug.cgi?id=1185764
# We can't use "systemctl reload-or-try-restart" since systemctl might
# be out of sync with reality.
/usr/share/pcp/lib/pmlogger condrestart

%if %{defined build_dashboard}
%package -n cockpit-dashboard
Summary: Cockpit remote servers and dashboard
%if 0%{?rhel} == 7
Provides: cockpit-ssh = %{version}-%{release}
# nothing depends on the dashboard, but we can't use it with older versions of the bridge
Conflicts: cockpit-bridge < 135
# PR #10430 dropped workaround for ws' inability to understand x-host-key challenge
Conflicts: cockpit-ws < 173.1
%else
BuildArch: noarch
Requires: cockpit-ssh >= 135
Conflicts: cockpit-ws < 135
%endif

%description -n cockpit-dashboard
Cockpit support for connecting to remote servers (through ssh),
bastion hosts, and a basic dashboard.

%files -n cockpit-dashboard -f dashboard.list

%endif

%ifarch x86_64 %{arm} aarch64 ppc64le i686 s390x

%if 0%{?fedora} || 0%{?rhel} < 8
%package -n cockpit-docker
Summary: Cockpit user interface for Docker containers
Requires: cockpit-bridge >= 122
Requires: cockpit-shell >= 122
Requires: /usr/bin/docker
Requires: /usr/lib/systemd/system/docker.service
%if 0%{?fedora}
Requires: %{__python3}
%else
Requires: python2
%endif

%description -n cockpit-docker
The Cockpit components for interacting with Docker and user interface.
This package is not yet complete.

%files -n cockpit-docker -f docker.list

%endif
%endif

%if 0%{?build_kubernetes}

%package -n cockpit-kubernetes
Summary: Cockpit user interface for Kubernetes cluster
Requires: /usr/bin/kubectl
# Requires: Needs newer localization support
Requires: cockpit-bridge >= 137.x
Requires: cockpit-shell >= 137.x
BuildRequires: %{go_scl_prefix}golang-bin
BuildRequires: %{go_scl_prefix}golang-src
Provides: cockpit-stub = %{version}-%{release}

%description -n cockpit-kubernetes
The Cockpit components for visualizing and configuring a Kubernetes
cluster. Installed on the Kubernetes master. This package is not yet complete.

%if 0%{?rhel} >= 7
%enable_gotoolset7
%endif

%files -n cockpit-kubernetes -f kubernetes.list
%{_libexecdir}/cockpit-kube-auth
%{_libexecdir}/cockpit-kube-launch
%{_libexecdir}/cockpit-stub
%endif

%package -n cockpit-packagekit
Summary: Cockpit user interface for packages
BuildArch: noarch
Requires: cockpit-bridge >= 138
Requires: PackageKit

%description -n cockpit-packagekit
The Cockpit components for installing OS updates and Cockpit add-ons,
via PackageKit.

%files -n cockpit-packagekit -f packagekit.list

%endif # build optional extension packages

%changelog
* Thu Dec 12 2019 Martin Pitt <mpitt@redhat.com> 195.6-1
- subscriptions: Avoid PackageKit when installing insights-client
  (rhbz#1768917)

* Thu Nov 07 2019 Martin Pitt <mpitt@redhat.com> 195.5-1
- subscriptions: Install insights-client on demand (rhbz#1768917)

* Wed Oct 16 2019 Martin Pitt <mpitt@redhat.com> 195.4-1
- Update translations (rhbz#1733994)

* Mon Sep 09 2019 Martin Pitt <mpitt@redhat.com> 195.3-1
- subscriptions: Add support for Red Hat Insights (rhbz#1748026)
- systemd: Warn if not connected to Insights (rhbz#1748350)

* Thu Aug 29 2019 Martin Pitt <mpitt@redhat.com> 195.2-1
- firewall: Only reload firewall when adding custom services (rhbz#1725094)
- networking: Activate a connection after clearing master/slave fields (rhbz#1729378)
- Add Obsoletes: for ancient cockpit-shell package (rhbz#1744208)

* Mon Jun 03 2019 Martin Pitt <mpitt@redhat.com> 195.1-1
- Update translations rhbz#1688228

* Thu Apr 04 2019 Martin Pitt <mpitt@redhat.com> 191-1
- System: Enable/disable SMT rhbz#1696139

* Mon Mar 25 2019 Martin Pitt <mpitt@redhat.com> 190-1
- kdump: Add NFS and SSH dump targets rhbz#1533366
- kdump: Fix confusing design of target selector rhbz#1536327
- firewall: Hide already enabled items from "Add Services" dialog rhbz#1598625
- networking: Gracefully handle when NetworkManager is  not running
  rhbz#1551615
- web server: Mark deleted cookie as "secure", and add X-Content-Type-Options
  header rhbz#1677767
- web server: Mark deleted cookie as "HttpOnly" rhbz#1656339
- Fix various crashes spotted by coverity rhbz#1644209
- Fix remotectl crash with inaccessible files rhbz#1644213
- Fix race condition with fslist1 channels rhbz#1644223
- Fix crash with parsing invalid bas64 headers rhbz#1663712

* Tue Oct 30 2018 Martin Pitt <mpitt@redhat.com> 173.1-1
- Crash fixes spotted by coverity rhbz#1644345
- Fix race condition with fslist channels rhbz#1644346
- Fix remotectl crash on errors rhbz#1644348

* Tue Sep 25 2018 Martin Pitt <mpitt@redhat.com> 173-7
- Build against fixed build root with all architectures again rhbz#1628490

* Wed Sep 12 2018 Martin Pitt <mpitt@redhat.com> 173-6
- Fix remote unauthenticated crash with crafted URLs rhbz#1627631
- Fix off-by-one error in flow control rhbz#1626846

* Tue Aug 21 2018 Martin Pitt <mpitt@redhat.com> 173-5
- Storage: Fix crash when cancelling package install
- Update translations rhbz#1569423

* Thu Jul 26 2018 Martin Pitt <mpitt@redhat.com> 173-1
- Rebase to version 173 rhbz#1568728

* Thu Jul 12 2018 Martin Pitt <mpitt@redhat.com> 172-1
- Rebase to version 172 rhbz#1568728

* Wed Jun 27 2018 Martin Pitt <mpitt@redhat.com> 171-1
- Rebase to version 171 rhbz#1568728

* Tue Jun 05 2018 Martin Pitt <mpitt@redhat.com> 169-3
- Rebase to version 169, drop all patches rhbz#1568728
- Fix Subscriptions page hang when accessing as non-admin rhbz#1442540
- Show an indicator on front page if updates are available rhbz#1495543
- Properly localize "Log in" rhbz#1541454
- Improve check for root privilege availability, to e. g. also work for FreeIPA
  admins rhbz#1574630

* Mon Jan 08 2018 Martin Pitt <mpitt@redhat.com> 154-3
- Update source po for Japanese translations rhbz#1512923
- Adjust build system to avoid build failure for the above

* Mon Dec 11 2017 Martin Pitt <mpitt@redhat.com> 154-2
- Update Japanese translations rhbz#1512923

* Tue Oct 17 2017 Martin Pitt <mpitt@redhat.com> 154-1
- Rebase to version 154, drop all patches rhbz#1470780
- This allows ssh keys to be loaded from arbitrary directories
  rhbz#1425887

* Thu Jun 22 2017 Dominik Perpeet <dperpeet@redhat.com> 138-9
- Add Japanese translation rhbz#1461085

* Wed May 24 2017 Dominik Perpeet <dperpeet@redhat.com> 138-8
- Rebuild for new dependencies

* Wed May 17 2017 Dominik Perpeet <dperpeet@redhat.com> 138-7
- Build cockpit-docker for s390x

* Wed May 17 2017 Dominik Perpeet <dperpeet@redhat.com> 138-6
- Fix ssh dependency

* Fri May 12 2017 Dominik Perpeet <dperpeet@redhat.com> 138-5
- Fix forwarding binary data in the shell
- Fix dashboard dependency

* Fri May 05 2017 Dominik Perpeet <dperpeet@redhat.com> 138-4
- Bump and rebuild on more architectures

* Wed May 03 2017 Dominik Perpeet <dperpeet@redhat.com> 138-3
- Fix issues with connections between multiple hosts
- Fix format string type mismatch on some architectures

* Tue May 02 2017 Dominik Perpeet <dperpeet@redhat.com> 138-2
- Bump and rebuild with dashboard

* Mon Apr 10 2017 Dominik Perpeet <dperpeet@redhat.com> 138-1
- Update to 138 release
- Simplify protocol that cockpit talks to session authentication processes

* Fri Mar 31 2017 Dominik Perpeet <dperpeet@redhat.com> 137-1
- Update to 137 release
- Cockpit's web server understands and properly responds to HTTP HEAD requests

* Mon Mar 27 2017 Dominik Perpeet <dperpeet@redhat.com> 136-1
- Update to 136 release
- Reorder menu items in a more logical way

* Thu Mar 23 2017 Dominik Perpeet <dperpeet@redhat.com> 135-4
- The cockpit package doesn't require the dashboard anymore
- The dashboard package conflicts with older bridge and ws versions

* Tue Mar 21 2017 Dominik Perpeet <dperpeet@redhat.com> 135-3
- Update to 135 release
- Redesigned page menu and machine switcher
- Show /etc/motd in the "System" page
- Allow changing the MAC address for ethernet adapters and see them for bonds
- NetworkManager now activates slave interfaces by itself
- Show "Locked/Unlocked" indicator for privilege escalation in the top bar
- Privilege escalation works with sudo reauthorization
- Use official /etc/ssh/ssh_known_hosts when connecting to remote hosts

* Tue Feb 14 2017 Dominik Perpeet <dperpeet@redhat.com> 131-3
- Fix size of list heading rhbz#1422184
- Fix button tooltips rhbz#1365372 rhbz#1412036
- Make basic selinux functionality available without rhbz#1422181

* Tue Feb 07 2017 Stef Walter <stefw@redhat.com> 131-2
- Actually build cockpit-dashboard sub-package

* Tue Feb 07 2017 Stef Walter <stefw@redhat.com> 131-1
- Update to 131 release
- Support for configuring kdump kernel crash dumping
- Support for rebasing OSTrees and configuring OSTree remotes
- Cockpit now respects /etc/shells and prevents login when user has an invalid shell
- Add a 'LoginTo' option in cockpit.conf to toggle ability to login to other servers
- Validate textual input on the Networking page properly

* Thu Dec 15 2016 Dominik Perpeet <dperpeet@redhat.com> 126-1
- Update to 126 release
- Show security scan information about containers
- During login users can choose whether password is cached and reused
- Allow renaming of active devices in networking interface
- More clearly indicate when checking network connectivity
- Allow more time for rollback when making network changes rhbz#1395108
- The remotectl command can now combine certificate and key files
- Domain join operations can now be properly cancelled
- Make Kerberos authentication work even if gss-proxy is in use
- When proxied, support X-Forwarded-Proto
- Ignore block devices with a zero size in the storage interface

* Tue Dec 13 2016 Dominik Perpeet <dperpeet@redhat.com> 125-1
- Update to 125 release
- Display OSTree signatures on Atomic Host
- Expand logical volumes and partitions inline on their devices
- No longer offer to format read-only block devices
- Use stored passphrases for LUKS devices properly
- System shutdown can be scheduled by date
- Properly terminate user sessions on the Accounts page
- Fix regression on login screen in older Internet Explorer browsers

* Mon Nov 14 2016 Dominik Perpeet <dperpeet@redhat.com> 122-3
- Fix regression when activating virtual network interfaces rhbz#1394667
- Support network connections that don't have an interface name rhbz#1394668
- Fix registry console Windows IE and Edge login rhbz#1378810 rhbz#1393740
- Fix reloading of projects and users in kubernetes rhbz#1393785
- Only set websocket protocols if they are available rhbz#1394675

* Tue Nov 08 2016 Dominik Perpeet <dperpeet@redhat.com> 122-2
- Fix default flags for new VLAN devices rhbz#1390605

* Tue Nov 01 2016 Dominik Perpeet <dperpeet@redhat.com> 122-1
- Update to 122 release
- Cockpit can rollback network configuration that would otherwise disconnect an admin from the system
- Unmanaged network devices are now shown
- The list of Docker containers can be filtered and expanded inline
- Cockpit can be a "bastion host" by using the login page to connect to an alternate system via SSH
- Only connect to an alternate system if it has a known SSH host key
- When connecting to other systems, each SSH connection is run in a separate process
- Fixes bugs that prevent the "Logs" page from working in Firefox 49
- A network proxy can be used when registering with RHEL subscriptions rhbz#1338681

* Tue Sep 20 2016 Dominik Perpeet <dperpeet@redhat.com> 118-2
- Turn off Cockpit debug session

* Wed Sep 07 2016 Dominik Perpeet <dperpeet@redhat.com> 118-1
- Update to 118 release
- SELinux audit failures can be diagnosed and solutions applied to the system
- Configure storage for Docker containers and images
- Volumes and environment variables can be configured for Docker containers
- Support PAM conversations on the Login screen, enabling two factor authentication
- Cockpit URLs can be proxied with a configured HTTP path prefix
- Timer jobs in systemd can be created and configured
- Display all managed NetworkManager devices
- Add support for network teams
- Prevent removal of last volume from volume group rhbz#1354421

* Fri Jul 15 2016 Dominik Perpeet <dperpeet@redhat.com> - 0.114-2
- The API of cockpit-bridge and cockpit-shell is now stable, other components
  only depend on a version >= 0.114 now, not an exact match to their own version

* Tue Jul 12 2016 Dominik Perpeet <dperpeet@redhat.com> - 0.114-1
- Update to 0.114 release
- Red Hat Subscriptions can now specify activation keys and orgs rhbz#1338680
- Network configuration of the Ethernet MTU rhbz#1339552
- SSH Host keys are show on system page rhbz#1318414
- Properly show SSH keys on authentication page rhbz#1336686
- Use 'active-backup' as the default for new network bonds rhbz#1348066
- Don't show network interfaces where NM_CONTROLLED=no is set rhbz#1330552
- Disable tuned correctly when clearing a performance profile rhbz#1330473
- Use CockpitLang cookie and Accept-Language for localization
- Cockpit terminal now supports shells like fish
- Disable the network on/off switch for unknown or unmanaged interfaces
  rhbz#1329954 rhbz#1329956
- Show intelligent password score error messages rhbz#1330838
- Show full string for system hardware info and operating system name rhbz#1331243
- Ensure popup-info when creating an account remains on screen rhbz#1340749
- Remove erroneous docker dependency rhbz#1349375

* Tue May 31 2016 Dominik Perpeet <dperpeet@redhat.com> - 0.108-1
- Update to 0.108 release
- Strict browser security policy for Cockpit is now enforced. This defines which code can be run in a Cockpit session and mitigates a number of browser based attacks.

* Tue Apr 19 2016 Dominik Perpeet <dperpeet@redhat.com> - 0.103-1
- Update to 0.103 release
- When Cockpit fails to connect to a host, relevant SSH command or host details are displayed to help resolve the issue
- Docker restart policy can be configured when starting a new container
- Display a single combined dialog for creating logical volumes
- Don't offer a 'Computer OU' option when joining IPA domains
- Display binary journal data correctly
- Display IEC names (eg: MiB) for disk or file system sizes
- Refuse to shrink logical volumes and prevent negative sizes in file system partition dialogs
- Apply strict Content-Security-Policy on most of Cockpit to prevent a number of browser based attacks
- Numerous other bug fixes and admin interface improvements

* Thu Mar 10 2016 Dominik Perpeet <dperpeet@redhat.com> - 0.96-2
- Fix selenium tests
- Fix issue with dwz / go binaries in packages

* Thu Mar 3 2016 Dominik Perpeet <dperpeet@redhat.com> - 0.96-1
- Update to 0.96 release
- Fix memory leaks, mostly related to DBus code
- Compatible with docker 1.10
- Limit concurrent authentication similar to sshd using 'MaxStartups' setting
- Fixed up server disconnection UI
- Navigation fixes

* Wed Feb 10 2016 Dominik Perpeet <dperpeet@redhat.com> - 0.93-3
- Fix session path rhbz#1306145

* Mon Feb 8 2016 Stef Walter <stefw@redhat.com> - 0.93-2
- Fix startup /dev/urandom read issue rhbz#1303582

* Mon Jan 25 2016 Dominik Perpeet <dperpeet@redhat.com> - 0.93-1
- Add tuned support
- Exit on idle in cockpit-ws

* Thu Jan 21 2016 Dominik Perpeet <dperpeet@redhat.com> - 0.92-1
- Add OAuth login support
- Make SOS report work on Atomic

* Mon Jan 18 2016 Stef Walter <stefw@redhat.com> - 0.91-2
- Depend on correct rpm-ostree RPM on RHEL

* Fri Jan 15 2016 Dominik Perpeet <dperpeet@redhat.com> - 0.91-1
- Update to 0.91 release
- Fix Cockpit session issues with a second machine rhbz#1277938
- Split out docker rhbz#1297797
- Distribute licenses of included components in the source rpm
- Reworked TLS certificates for Cockpit
- Remove custom SELinux policy
- SOS report UI page
- User interface for OSTree upgrades and rollbacks
- Offer to activate multipathd for multipath disks

* Thu Oct 08 2015 Peter <petervo@redhat.com> - 0.77-3
- Update cockpit.pam to include pam_reauthorize and pam_ssh_add rhbz#1269623

* Wed Sep 30 2015 Stef Walter <stefw@redhat.com> - 0.77-2
- Fix extreme CPU usage bug rhbz#1266503
- Fix regressions in 0.77 rhbz#1266566

* Tue Sep 22 2015 Stef Walter <stefw@redhat.com> - 0.77-1
- Work better with multipath storage
- Deletion of kubernetes objects
- Cleaner URLs in the bookmark bar
- Show a warning when adding too many machines
- Make authentication work when embedding Cockpit
- Complete componentizing Cockpit

* Thu Aug 13 2015 Stef Walter <stefw@redhat.com> - 0.70-2
- kubernetes-client is not available on kubernetes yet

* Wed Aug 12 2015 Stef Walter <stefw@redhat.com> - 0.70-1
- Update to 0.70 release
- Depend on kubernetes-client instead of kubernetes

* Thu Aug 06 2015 Stef Walter <stefw@redhat.com> - 0.69-1
- Update to 0.69 release.

* Wed Jul 29 2015 Peter <petervo@redhat.com> - 0.68-1
- Update to 0.68 release.

* Thu Jul 23 2015 Peter <petervo@redhat.com> - 0.66-1
- Update to 0.66 release

* Fri Jul 17 2015 Peter <petervo@redhat.com> - 0.65-2
- Require libssh 0.7.1 on fedora >= 22 systems

* Wed Jul 15 2015 Peter <petervo@redhat.com> - 0.65-1
- Update to 0.65 release

* Wed Jul 08 2015 Peter <petervo@redhat.com> - 0.64-1
- Update to 0.64 release

* Wed Jul 01 2015 Peter <petervo@redhat.com> - 0.63-1
- Update to 0.63 release
- Remove cockpit-docker for armv7hl while docker
  packages are being fixed

* Thu Jun 25 2015 Peter <petervo@redhat.com> - 0.62-1
- Update to 0.62 release

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.61-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Wed Jun 10 2015 Peter <petervo@redhat.com> - 0.61-1
- Update to 0.61 release

* Mon Jun 01 2015 Stef Walter <stefw@redhat.com> - 0.60-1
- Update to 0.60 release

* Wed May 27 2015 Peter <petervo@redhat.com> - 0.59-1
- Update to 0.59 release

* Fri May 22 2015 Peter <petervo@redhat.com> - 0.58-1
- Update to 0.58 release

* Wed May 20 2015 Peter <petervo@redhat.com> - 0.57-1
- Update to 0.57 release

* Wed May 13 2015 Peter <petervo@redhat.com> - 0.56-1
- Update to 0.56 release

* Wed May 06 2015 Stef Walter <stefw@redhat.com> - 0.55-1
- Update to 0.55 release

* Fri Apr 24 2015 Peter <petervo@redhat.com> - 0.54-1
- Update to 0.54 release

* Tue Apr 21 2015 Peter <petervo@redhat.com> - 0.53-1
- Update to 0.53 release

* Thu Apr 16 2015 Stef Walter <stefw@redhat.com> - 0.52-1
- Update to 0.52 release

* Tue Apr 14 2015 Peter <petervo@redhat.com> - 0.51-1
- Update to 0.51 release

* Tue Apr 07 2015 Stef Walter <stefw@redhat.com> - 0.50-1
- Update to 0.50 release

* Wed Apr 01 2015 Stephen Gallagher <sgallagh@redhat.com> 0.49-2
- Fix incorrect Obsoletes: of cockpit-daemon

* Wed Apr 01 2015 Peter <petervo@redhat.com> - 0.49-1
- Update to 0.49 release.
- cockpitd was renamed to cockpit-wrapper the cockpit-daemon
  package was removed and is now installed with the
  cockpit-bridge package.

* Mon Mar 30 2015 Peter <petervo@redhat.com> - 0.48-1
- Update to 0.48 release

* Mon Mar 30 2015 Stephen Gallagher <sgallagh@redhat.com> 0.47-2
- Don't attempt to build cockpit-kubernetes on armv7hl

* Fri Mar 27 2015 Peter <petervo@redhat.com> - 0.47-1
- Update to 0.47 release, build docker on armvrhl

* Thu Mar 26 2015 Stef Walter <stefw@redhat.com> - 0.46-1
- Update to 0.46 release

* Mon Mar 23 2015 Stef Walter <stefw@redhat.com> - 0.45-1
- Update to 0.45 release

* Sat Mar 21 2015 Stef Walter <stefw@redhat.com> - 0.44-3
- Add back debuginfo files to the right place

* Fri Mar 20 2015 Stef Walter <stefw@redhat.com> - 0.44-2
- Disable separate debuginfo for now: build failure

* Fri Mar 20 2015 Stef Walter <stefw@redhat.com> - 0.44-1
- Update to 0.44 release

* Thu Mar 19 2015 Stef Walter <stefw@redhat.com> - 0.43-2
- Don't break EPEL or CentOS builds due to missing branding

* Wed Mar 18 2015 Stef Walter <stefw@redhat.com> - 0.43-1
- Update to 0.43 release

* Tue Mar 17 2015 Stef Walter <stefw@redhat.com> - 0.42-2
- Fix obseleting cockpit-assets

* Sat Mar 14 2015 Stef Walter <stefw@redhat.com> - 0.42-1
- Update to 0.42 release

* Wed Mar 04 2015 Stef Walter <stefw@redhat.com> - 0.41-1
- Update to 0.41 release

* Thu Feb 26 2015 Stef Walter <stefw@redhat.com> - 0.40-1
- Update to 0.40 release

* Thu Feb 19 2015 Stef Walter <stefw@redhat.com> - 0.39-1
- Update to 0.39 release

* Wed Jan 28 2015 Stef Walter <stefw@redhat.com> - 0.38-1
- Update to 0.38 release

* Thu Jan 22 2015 Stef Walter <stefw@redhat.com> - 0.37-1
- Update to 0.37 release

* Mon Jan 12 2015 Stef Walter <stefw@redhat.com> - 0.36-1
- Update to 0.36 release

* Mon Dec 15 2014 Stef Walter <stefw@redhat.com> - 0.35-1
- Update to 0.35 release

* Thu Dec 11 2014 Stef Walter <stefw@redhat.com> - 0.34-1
- Update to 0.34 release

* Fri Dec 05 2014 Stef Walter <stefw@redhat.com> - 0.33-3
- Only depend on docker stuff on x86_64

* Fri Dec 05 2014 Stef Walter <stefw@redhat.com> - 0.33-2
- Only build docker stuff on x86_64

* Wed Dec 03 2014 Stef Walter <stefw@redhat.com> - 0.33-1
- Update to 0.33 release

* Mon Nov 24 2014 Stef Walter <stefw@redhat.com> - 0.32-1
- Update to 0.32 release

* Fri Nov 14 2014 Stef Walter <stefw@redhat.com> - 0.31-1
- Update to 0.31 release

* Wed Nov 12 2014 Stef Walter <stefw@redhat.com> - 0.30-1
- Update to 0.30 release
- Split Cockpit into various sub packages

* Wed Nov 05 2014 Stef Walter <stefw@redhat.com> - 0.29-3
- Don't require test-assets from selinux-policy
- Other minor tweaks and fixes

* Wed Nov 05 2014 Stef Walter <stefw@redhat.com> - 0.29-2
- Include selinux policy as a dep where required

* Wed Nov 05 2014 Stef Walter <stefw@redhat.com> - 0.29-1
- Update to 0.29 release

* Thu Oct 16 2014 Stef Walter <stefw@redhat.com> - 0.28-1
- Update to 0.28 release
- cockpit-agent was renamed to cockpit-bridge

* Fri Oct 10 2014 Stef Walter <stefw@redhat.com> - 0.27-1
- Update to 0.27 release
- Don't create cockpit-*-admin groups rhbz#1145135
- Fix user management for non-root users rhbz#1140562
- Fix 'out of memory' error during ssh auth rhbz#1142282

* Wed Oct 08 2014 Stef Walter <stefw@redhat.com> - 0.26-1
- Update to 0.26 release
- Can see disk usage on storage page rhbz#1142459
- Better order for lists of block devices rhbz#1142443
- Setting container memory limit fixed rhbz#1142362
- Can create storage volume of maximum capacity rhbz#1142259
- Fix RAID device Bitmap enable/disable error rhbz#1142248
- Docker page connects to right machine rhbz#1142229
- Clear the format dialog label correctly rhbz#1142228
- No 'Drop Privileges' item in menu for root rhbz#1142197
- Don't flash 'Server has closed Connection on logout rhbz#1142175
- Non-root users can manipulate user accounts rhbz#1142154
- Fix strange error message when editing user accounts rhbz#1142154

* Wed Sep 24 2014 Stef Walter <stefw@redhat.com> - 0.25-1
- Update to 0.25 release

* Wed Sep 17 2014 Stef Walter <stefw@redhat.com> - 0.24-1
- Update to 0.24 release

* Wed Sep 10 2014 Stef Walter <stefw@redhat.com> - 0.23-1
- Update to 0.23 release

* Wed Sep 03 2014 Stef Walter <stefw@redhat.com> - 0.22-1
- Update to 0.22 release

* Tue Aug 26 2014 Patrick Uiterwijk <puiterwijk@redhat.com> - 0.21-1
- Update to 0.21 release

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.20-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Thu Aug 14 2014 Stef Walter <stefw@redhat.com> 0.20-1
- Update to 0.20 release

* Thu Aug 07 2014 Stef Walter <stefw@redhat.com> 0.19-1
- Update to 0.19 release

* Wed Jul 30 2014 Stef Walter <stefw@redhat.com> 0.18-1
- Update to 0.18 release
- Add glib-networking build requirement
- Let selinux-policy-targetted distribute selinux policy

* Mon Jul 28 2014 Colin Walters <walters@verbum.org> 0.17-2
- Drop Requires and references to dead test-assets subpackage

* Thu Jul 24 2014 Stef Walter <stefw@redhat.com> 0.17-1
- Update to 0.17 release

* Wed Jul 23 2014 Stef Walter <stefw@redhat.com> 0.16-3
- Distribute our own selinux policy rhbz#1110758

* Tue Jul 22 2014 Stef Walter <stefw@redhat.com> 0.16-2
- Refer to cockpit.socket in scriptlets rhbz#1110764

* Thu Jul 17 2014 Stef Walter <stefw@redhat.com> 0.16-1
- Update to 0.16 release

* Thu Jul 10 2014 Stef Walter <stefw@redhat.com> 0.15-1
- Update to 0.15 release
- Put pam_reauthorize.so in the cockpit PAM stack

* Thu Jul 03 2014 Stef Walter <stefw@redhat.com> 0.14-1
- Update to 0.14 release

* Mon Jun 30 2014 Stef Walter <stefw@redhat.com> 0.13-1
- Update to 0.13 release

* Tue Jun 24 2014 Stef Walter <stefw@redhat.com> 0.12-1
- Update to upstream 0.12 release

* Fri Jun 20 2014 Stef Walter <stefw@redhat.com> 0.11-1
- Update to upstream 0.11 release

* Thu Jun 12 2014 Stef Walter <stefw@redhat.com> 0.10-1
- Update to upstream 0.10 release

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri May 23 2014 Stef Walter <stefw@redhat.com> 0.9-1
- Update to upstream 0.9 release
- Fix file attribute for cockpit-polkit

* Wed May 21 2014 Stef Walter <stefw@redhat.com> 0.8-1
- Update to upstream 0.8 release
- cockpitd now runs as a user session DBus service

* Mon May 19 2014 Stef Walter <stefw@redhat.com> 0.7-1
- Update to upstream 0.7 release

* Wed May 14 2014 Stef Walter <stefw@redhat.com> 0.6-1
- Update to upstream 0.6 release

* Tue Apr 15 2014 Stef Walter <stefw@redhat.com> 0.5-1
- Update to upstream 0.5 release

* Thu Apr 03 2014 Stef Walter <stefw@redhat.com> 0.4-1
- Update to upstream 0.4 release
- Lots of packaging cleanup and polish

* Fri Mar 28 2014 Stef Walter <stefw@redhat.com> 0.3-1
- Update to upstream 0.3 release

* Wed Feb 05 2014 Patrick Uiterwijk (LOCAL) <puiterwijk@redhat.com> - 0.2-0.4.20140204git5e1faad
- Redid the release tag

* Tue Feb 04 2014 Patrick Uiterwijk (LOCAL) <puiterwijk@redhat.com> - 0.2-0.3.5e1faadgit
- Fixed license tag
- Updated to new FSF address upstream
- Removing libgsystem before build
- Now claiming specific manpages
- Made the config files noreplace
- Removed the test assets
- Put the web assets in a subpackage

* Tue Feb 04 2014 Patrick Uiterwijk (LOCAL) <puiterwijk@redhat.com> - 0.2-0.2.5e1faadgit
- Patch libgsystem out
